@@ -70,9 +70,9 @@ static inline void skb_reset(struct sk_buff *skb)
 	skb->mac_len = 0;
 	skb->dev = NULL;
 	skb->hdr_len = skb_headroom(skb);
-	skb->mac_header = (typeof(skb->mac_header))~0U;
-	skb->transport_header = (typeof(skb->transport_header))~0U;
+	skb_reset_mac_header(skb);
 	skb_reset_network_header(skb);
+	skb_probe_transport_header(skb, 0);
 }
 
 static inline void skb_encrypt(struct sk_buff *skb, struct packet_data_encryption_ctx *ctx)
@@ -234,7 +234,7 @@ int packet_create_data(struct sk_buff *skb, struct wireguard_peer *peer, void(*c
 	ctx->keypair = keypair;
 
 #ifdef CONFIG_WIREGUARD_PARALLEL
-	if (parallel && cpumask_weight(cpu_online_mask) > 1) {
+	if ((parallel || padata_queue_len(peer->device->parallel_send) > 0) && cpumask_weight(cpu_online_mask) > 1) {
 		unsigned int cpu = choose_cpu(keypair->remote_index);
 		ret = start_encryption(peer->device->parallel_send, &ctx->padata, cpu);
 		if (unlikely(ret < 0))
