@@ -44,7 +44,9 @@ enum limits {
 	REKEY_AFTER_TIME = 120 * HZ,
 	REJECT_AFTER_TIME = 180 * HZ,
 	INITIATIONS_PER_SECOND = HZ / 50,
-	MAX_PEERS_PER_DEVICE = U16_MAX
+	MAX_PEERS_PER_DEVICE = U16_MAX,
+	KEEPALIVE_TIMEOUT = 10 * HZ,
+	MAX_TIMER_HANDSHAKES = (90 * HZ) / REKEY_TIMEOUT
 };
 
 enum message_type {
