@@ -5,15 +5,10 @@
 #include "peer.h"
 #include "packets.h"
 
-enum {
-	KEEPALIVE = 10 * HZ,
-	MAX_TIMER_HANDSHAKES = (90 * HZ) / REKEY_TIMEOUT
-};
-
 /*
  * Timer for retransmitting the handshake if we don't hear back after `REKEY_TIMEOUT` ms
- * Timer for sending empty packet if we have received a packet but after have not sent one for `KEEPALIVE` ms
- * Timer for initiating new handshake if we have sent a packet but after have not received one (even empty) for `(KEEPALIVE + REKEY_TIMEOUT)` ms
+ * Timer for sending empty packet if we have received a packet but after have not sent one for `KEEPALIVE_TIMEOUT` ms
+ * Timer for initiating new handshake if we have sent a packet but after have not received one (even empty) for `(KEEPALIVE_TIMEOUT + REKEY_TIMEOUT)` ms
  * Timer for zeroing out all ephemeral keys after `(REJECT_AFTER_TIME * 3)` ms if no new keys have been received
  * Timer for, if enabled, sending an empty authenticated packet every user-specified seconds
  */
@@ -34,6 +29,10 @@ static void expired_retransmit_handshake(unsigned long ptr)
 		/* We remove all existing packets and don't try again,
 		 * if we try unsuccessfully for too long to make a handshake. */
 		skb_queue_purge(&peer->tx_packet_queue);
+		/* We set a timer for destroying any residue that might be left
+		 * of a partial exchange. */
+		if (likely(peer->timer_kill_ephemerals.data))
+			mod_timer(&peer->timer_kill_ephemerals, jiffies + (REJECT_AFTER_TIME * 3));
 		return;
 	}
 	packet_queue_send_handshake_initiation(peer);
@@ -44,11 +43,10 @@ static void expired_send_keepalive(unsigned long ptr)
 {
 	struct wireguard_peer *peer = (struct wireguard_peer *)ptr;
 
-	pr_debug("Sending keep alive packet to peer %Lu (%pISpfsc), since we received data, but haven't sent any for %d seconds\n", peer->internal_id, &peer->endpoint_addr, KEEPALIVE / HZ);
 	packet_send_keepalive(peer);
 	if (peer->timer_need_another_keepalive) {
 		peer->timer_need_another_keepalive = false;
-		mod_timer(&peer->timer_send_keepalive, jiffies + KEEPALIVE);
+		mod_timer(&peer->timer_send_keepalive, jiffies + KEEPALIVE_TIMEOUT);
 	}
 }
 
@@ -56,7 +54,7 @@ static void expired_new_handshake(unsigned long ptr)
 {
 	struct wireguard_peer *peer = (struct wireguard_peer *)ptr;
 
-	pr_debug("Retrying handshake with peer %Lu (%pISpfsc) because we stopped hearing back after %d seconds\n", peer->internal_id, &peer->endpoint_addr, (KEEPALIVE + REKEY_TIMEOUT) / HZ);
+	pr_debug("Retrying handshake with peer %Lu (%pISpfsc) because we stopped hearing back after %d seconds\n", peer->internal_id, &peer->endpoint_addr, (KEEPALIVE_TIMEOUT + REKEY_TIMEOUT) / HZ);
 	packet_queue_send_handshake_initiation(peer);
 }
 
@@ -89,7 +87,6 @@ static void expired_send_persistent_keepalive(unsigned long ptr)
 
 	if (unlikely(!peer->persistent_keepalive_interval))
 		return;
-	pr_debug("Sending keep alive packet to peer %Lu (%pISpfsc), since we haven't sent or received authenticated data for %lu seconds\n", peer->internal_id, &peer->endpoint_addr, peer->persistent_keepalive_interval / HZ);
 	packet_send_keepalive(peer);
 }
 
@@ -100,14 +97,14 @@ void timers_data_sent(struct wireguard_peer *peer)
 		del_timer(&peer->timer_send_keepalive);
 
 	if (likely(peer->timer_new_handshake.data) && !timer_pending(&peer->timer_new_handshake))
-		mod_timer(&peer->timer_new_handshake, jiffies + KEEPALIVE + REKEY_TIMEOUT);
+		mod_timer(&peer->timer_new_handshake, jiffies + KEEPALIVE_TIMEOUT + REKEY_TIMEOUT);
 }
 
 /* Should be called after an authenticated data packet is received. */
 void timers_data_received(struct wireguard_peer *peer)
 {
 	if (likely(peer->timer_send_keepalive.data) && !timer_pending(&peer->timer_send_keepalive))
-		mod_timer(&peer->timer_send_keepalive, jiffies + KEEPALIVE);
+		mod_timer(&peer->timer_send_keepalive, jiffies + KEEPALIVE_TIMEOUT);
 	else
 		peer->timer_need_another_keepalive = true;
 }
@@ -125,7 +122,7 @@ void timers_handshake_initiated(struct wireguard_peer *peer)
 	if (likely(peer->timer_send_keepalive.data))
 		del_timer(&peer->timer_send_keepalive);
 	if (likely(peer->timer_retransmit_handshake.data))
-		mod_timer(&peer->timer_retransmit_handshake, jiffies + REKEY_TIMEOUT);
+		mod_timer(&peer->timer_retransmit_handshake, slack_time(jiffies + REKEY_TIMEOUT + HZ / 4));
 }
 
 /* Should be called after a handshake response message is received and processed. */
