@@ -6,7 +6,7 @@
 #include <string.h>
 
 #include "config.h"
-#include "kernel.h"
+#include "ipc.h"
 #include "subcommands.h"
 
 int setconf_main(int argc, char *argv[])
@@ -45,7 +45,7 @@ int setconf_main(int argc, char *argv[])
 	strncpy(device->interface, argv[1], IFNAMSIZ - 1);
 	device->interface[IFNAMSIZ - 1] = 0;
 
-	if (kernel_set_device(device) != 0) {
+	if (ipc_set_device(device) != 0) {
 		perror("Unable to set device");
 		goto cleanup;
 	}
